==> xwiki-rendering-syntax-xhtml-13.3-rc-1-sources.jar: org/xwiki/rendering/internal/renderer/xhtml/XHTMLRendererFactory.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.internal.renderer.xhtml;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.rendering.internal.renderer.AbstractPrintRendererFactory;
import org.xwiki.rendering.internal.xhtml.XHTML10SyntaxProvider;
import org.xwiki.rendering.syntax.Syntax;

/**
 * Create XHTML Renderers.
 *
 * @version $Id: c82a231902e2ce16e20c5039cd49a73dc5773137 $
 * @since 2.0M3
 */
@Component
@Named("xhtml/1.0")
@Singleton
public class XHTMLRendererFactory extends AbstractPrintRendererFactory
{
    @Override
    public Syntax getSyntax()
    {
        return XHTML10SyntaxProvider.XHTML_1_0;
    }
}

==> xwiki-rendering-syntax-xhtml-14.4.6-sources.jar: org/xwiki/rendering/internal/renderer/xhtml/XHTMLRendererFactory.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.internal.renderer.xhtml;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.rendering.internal.renderer.AbstractPrintRendererFactory;
import org.xwiki.rendering.syntax.Syntax;

import static org.xwiki.rendering.internal.xhtml.XHTML10SyntaxProvider.XHTML_1_0;

/**
 * Create XHTML Renderers.
 *
 * @version $Id: 002190c57aa75169010577f589c84f98885c2f2e $
 * @since 2.0M3
 */
@Component
@Named("xhtml/1.0")
@Singleton
public class XHTMLRendererFactory extends AbstractPrintRendererFactory
{
    @Override
    public Syntax getSyntax()
    {
        return XHTML_1_0;
    }
}
